import { AppNotification } from "../model/AppNotification";
import { BaseApi } from "./BaseApi";
interface INotificationApi {
    send(notification: AppNotification): Promise<void>;
    hide(): Promise<void>;
}
type NotificationApiMethods = keyof INotificationApi;
declare enum NotificationApiEvent {
    CONFIRM = "event::cn.widgetjs.core.notification.confirm",
    CANCEL = "event::cn.widgetjs.core.notification.cancel",
    HIDE = "event::cn.widgetjs.core.notification.hide"
}
declare class NotificationApiImpl extends BaseApi<NotificationApiMethods> implements INotificationApi {
    /**
     * 来电
     * @param avatar    头像地址
     * @param audio     音频地址
     * @param title     标题文件
     * @param message   初始消息
     * @param lyric     歌词字符串
     */
    call(avatar: string, audio: string, title: string, message: string, lyric: string): Promise<void>;
    send(notification: AppNotification): Promise<any>;
    reminder(title: string, message: string, icon: string, cancelButtonText: string, confirmButtonText: string, cancelBroadcast: string, confirmBroadcast: string, duration?: number): Promise<any>;
    advanceCountdown(message: string, targetTime: string, title?: string): Promise<any>;
    countdown(message: string, targetTime: string): Promise<void>;
    success(message: string, duration?: number): Promise<void>;
    error(message: string, duration?: number): Promise<void>;
    warning(message: string, duration?: number): Promise<void>;
    info(message: string, duration?: number): Promise<void>;
    /**
     * 隐藏通知
     */
    hide(): Promise<void>;
    getChannel(): string;
}
declare const NotificationApi: NotificationApiImpl;
export { NotificationApi, NotificationApiMethods, NotificationApiEvent };
