import { Widget } from "../model/Widget";
import { WidgetPackage } from "../model/WidgetPackage";
import { WidgetParams } from "../model/WidgetParams";
import { BaseApi } from "./BaseApi";
interface IWidgetApi {
    registerWidgets(widgets: Widget[]): Promise<void>;
    registerWidgetPackage(widgetPackage: WidgetPackage): Promise<void>;
    getWidgets(): Promise<Widget[]>;
    getWidget(name: string): Promise<Widget>;
    getWidgetPackage(name: string): Promise<WidgetPackage>;
    getWidgetPackages(): Promise<WidgetPackage[]>;
    getWidgetUrl(widgetName: string, widgetParams: WidgetParams): Promise<string | null>;
    getWidgetPackageIndexUrl(packageName: string, hash?: boolean): Promise<string | null>;
    getWidgetConfigUrl(widgetName: string, widgetParams: WidgetParams): Promise<string | null>;
    getWidgetPackageUrl(packageName: string): Promise<string | null>;
}
type WidgetApiMethods = keyof IWidgetApi;
declare enum WidgetApiEvent {
    DATA_CHANGED = "event::cn.widgetjs.core.widget.data-changed",
    EDIT_DESKTOP_WIDGETS = "event::cn.widgetjs.core.widget.desktop.edit"
}
declare class WidgetApiImpl extends BaseApi<WidgetApiMethods> implements IWidgetApi {
    getChannel(): string;
    registerWidgets(widgets: Widget[]): Promise<any>;
    registerWidgetPackage(widgetPackage: WidgetPackage): Promise<any>;
    getWidgets(): Promise<Widget[]>;
    getWidgetPackages(): Promise<WidgetPackage[]>;
    /**
     *
     * @param name package name
     */
    getWidget(name: string): Promise<Widget>;
    /**
     *
     * @param name package name
     */
    getWidgetPackage(name: string): Promise<WidgetPackage>;
    /**
     * 获取组件配置地址
     * @param widgetName
     */
    getWidgetConfigUrl(widgetName: string, widgetParams: WidgetParams): Promise<string | null>;
    getWidgetUrl(widgetName: string, widgetParams: WidgetParams): Promise<string | null>;
    getWidgetPackageIndexUrl(packageName: string, hash?: boolean): Promise<string | null>;
    getWidgetPackageUrl(packageName: string): Promise<string | null>;
}
declare const WidgetApi: WidgetApiImpl;
export { WidgetApi, WidgetApiEvent, WidgetApiMethods };
